#!/usr/bin/env python

from .io import read, write

__all__ = ['read', 'write']
